<?php
#
# PDFlib PLOP DS:
# Demonstrate digital signature features with optional signature visualization
#

try {
    # create a new PLOP object
    $plop = new PLOP();

    # Basic signature options
    $sign_opts =
        "ltv=try " .        /* use ltv=full to ensure LTV status */
        /* use the following line for PKCS11 usage
	"engine=pkcs#11 digitalid={filename=cryptoki.dll} "
	*/
        "engine=builtin digitalid={filename=demo_signer_rsa_2048.p12} password={demo} " ;


    # This is where input files live. Adjust as necessary.
    $searchpath = "../data ../../data";

    /* Set to true to enable signature visualization */
    $visualize = false;

    $infile = "invoice.pdf";
    $visfile = "signing_man_pdfa1a.pdf";
    $outfile = "";
    $optlist;

    $optlist = sprintf("searchpath={%s}", $searchpath);
    $plop->set_option($optlist);

    # Basic signature options
    $optlist = $sign_opts;

    if (($doc = $plop->open_document($infile, "")) == 0)
    {
	die("Error: " . $plop->get_apiname() . ": "
				 . $plop->get_errmsg() . "\n");
    }
    if ($visualize){
	if (($visdoc = $plop->open_document($visfile, "")) == 0)
	{
	    die("Error: " . $plop->get_apiname() . ": "
				     . $plop->get_errmsg() . "\n");
	}
	$optlist .= sprintf("field={visdoc=%d rect={50 50 adapt adapt}} ", $visdoc);
    }


    if ($plop->prepare_signature($optlist) == 0)
    {
	die("Error: " . $plop->get_apiname() . ": "
				 . $plop->get_errmsg() . "\n");
    }

    if ($plop->create_document($outfile, "input=". $doc) == 0)
    {
	die("Error: " . $plop->get_apiname() . ": "
				 . $plop->get_errmsg() . "\n");
    }

    $buf = $plop->get_buffer();
    $len = strlen($buf);

    header("Content-type: application/pdf");
    header("Content-Length: $len");
    header("Content-Disposition: inline; filename=sign.pdf");
    print $buf;

    $plop->close_document($doc, "");
    if ($visualize){
	$plop->close_document($visdoc, "");
    }
}
catch (PLOPException $e) {
    die("PLOP exception occurred in sign sample:\n" .
	"[" . $e->get_errnum() . "] " . $e->get_apiname() . ": " .
	$e->get_errmsg() . "\n");
    }
catch (Exception $e) {
    die($e);
}

$plop = 0;
